Improve this Doc

# Error: $animate:nongcls
`ng-animate` class not allowed

    $animateProvider.classNameFilter(regex) prohibits accepting a regex value which matches/contains the "{0}" CSS class.

## Description

This error occurs, when trying to set `$animateProvider.classNameFilter()` to a RegExp containing the reserved `ng-animate` class. Since `.ng-animate` will be added/removed by `$animate` itself, using it as part of the `classNameFilter` RegExp is not allowed.